//=====================================================================================================
// IMU.h
// S.O.H. Madgwick
// 25th September 2010
//=====================================================================================================
//
// See IMU.c file for description.
// 
//=====================================================================================================
#ifndef updateIMU_h
#define updateIMU_h

//----------------------------------------------------------------------------------------------------

#include "mbed.h"
// Variable declaration

#define PI 3.1415926536

class updateIMU {

public:
 /**
     * Constructor.
     *
     * Initializes filter variables.
     *
     * @param rate The rate at which the filter should be updated.
     * @param gyroscopeMeasurementError The error of the gyroscope in degrees
     *  per second. This used to calculate a tuning constant for the filter.
     *  Try changing this value if there are jittery readings, or they change
     *  too much or too fast when rotating the IMU.
     */

updateIMU(double rate);

    /**
     * Update the filter variables.
     *
     * @param w_x X-axis gyroscope reading in rad/s.
     * @param w_y Y-axis gyroscope reading in rad/s.
     * @param w_z Z-axis gyroscope reading in rad/s.
     * @param a_x X-axis accelerometer reading in m/s/s.
     * @param a_y Y-axis accelerometer reading in m/s/s.
     * @param a_z Z-axis accelerometer reading in m/s/s.
     */
     
void IMUupdate(double gx, double gy, double gz, double ax, double ay, double az);

    /**
     * Compute the Euler angles based on the current filter data.
     */
void computeEuler(void);

void getYawPitchRoll(float *ypr);

    /**
     * Get the current roll.
     *
     * @return The current roll angle in radians.
     */
double getRoll(void);

    /**
     * Get the current pitch.
     *
     * @return The current pitch angle in radians.
     */
double getPitch(void);

    /**
     * Get the current yaw.
     *
     * @return The current yaw angle in radians.
     */
double getYaw(void);

 //Estimated orientation quaternion elements with initial conditions.
    double q0;
    double q1;
    double q2;
    double q3;

private:

    // scaled integral error   
    double exInt;
    double eyInt;
    double ezInt;
    
     //Sampling period
    double deltat;
    
    double phi;
    double theta;
    double psi;

};


#endif
//=====================================================================================================
// End of file
//=====================================================================================================